import { browser } from "$app/environment";
import { getAuthInfo, makeAuthHeaderForAxios } from "$lib/auth/Auth";
import { makePost } from "$lib/tools/requests/requests";
import { sayError } from "$lib/tools/toaster/Toaster";
import { redirect } from "$lib/tools/url/URLTools";

export async function load({ params }) {
    if(!browser) return;
  const { userToken } = params;
  let userResult = await makePost(
    "getUser",
    {
      token: userToken,
    },
    makeAuthHeaderForAxios(getAuthInfo()?.a)
  );
  if (userResult.status === 401) {
    sayError("Данные авторизации устарели");
    // window.location.href = "/";
    redirect("/admin/");
    return {};
  }
  if (userResult.error) {
    sayError("Не удалось настроить пользователя");
    return {};
  }
  userResult["can_trade"] = userResult["can_trade"] === "t" ? true:false;
  userResult["can_trade_global"] = userResult["can_trade_global"] === "t" ? true:false;
  userResult["balance"] = Number(userResult["balance"]);
  userResult["bid"] = Number(userResult["bid"]);
  return {
    token: userToken,
    userData: userResult.data
  };
}